@@ -108,6 +108,8 @@ TICKS timerTicks = WRAPPER_TICK_INITIAL;
 
 TICKS stopSignalLastTick = WRAPPER_TICK_INITIAL;
 
+int handleSignals = TRUE;
+
 /** Flag which keeps track of whether or not PID files should be deleted on shutdown. */
 int cleanUpPIDFilesOnExit = FALSE;
 
@@ -120,6 +122,9 @@ int cleanUpPIDFilesOnExit = FALSE;
  */
 void appExit(int exitCode, int argc, TCHAR** argv) {
     int i;
+    
+    /* Stop handling signals (else it can cause crashes if the code uses disposed structures). */
+    handleSignals = FALSE;
 
     /* We only want to delete the pid files if we created them. Some Wrapper
      *  invocations are meant to run in parallel with Wrapper instances
@@ -337,6 +342,10 @@ void takeSignalAction(int sigNum, const TCHAR *sigName, int mode) {
  *  immediately to decrease the chance of missing duplicate signals.
  */
 void wrapperMaintainSignals() {
+    if (!handleSignals) {
+        return;
+    }
+    
     /* SIGINT */
     if (wrapperData->signalInterruptTrapped) {
         wrapperData->signalInterruptTrapped = FALSE;
@@ -2141,7 +2150,7 @@ int main(int argc, char **argv) {
             wrapperUsage(argv[0]);
         }
         /* There might have been some queued messages logged on configuration load. Queue the following message to make it appear last. */
-        log_printf_queue(TRUE, WRAPPER_SOURCE_WRAPPER, LEVEL_FATAL, TEXT("  The Wrapper will stop."));
+        log_printf_queue(TRUE, WRAPPER_SOURCE_WRAPPER, LEVEL_STATUS, TEXT("  The Wrapper will stop."));
         appExit(wrapperData->errorExitCode, argc, argv);
         return 1; /* For compiler. */
     }
@@ -2196,7 +2205,7 @@ int main(int argc, char **argv) {
                 if (wrapperSetWorkingDir(wrapperData->originalWorkingDir, TRUE)) {
                     /* Failed to restore the working dir.  Shutdown the Wrapper */
                     /* There might have been some queued messages logged on configuration load. Queue the following message to make it appear last. */
-                    log_printf_queue(TRUE, WRAPPER_SOURCE_WRAPPER, LEVEL_FATAL, TEXT("  The Wrapper will stop."));
+                    log_printf_queue(TRUE, WRAPPER_SOURCE_WRAPPER, LEVEL_STATUS, TEXT("  The Wrapper will stop."));
                     appExit(wrapperData->errorExitCode, argc, argv);
                     return 1; /* For compiler. */
                 }
