@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2018 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2020 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -174,6 +174,26 @@ Java_org_tanukisoftware_wrapper_WrapperManager_nativeInit(JNIEnv *env, jclass jC
     wrapperProcessId = getpid();
 }
 
+/*
+ * Class:     org_tanukisoftware_wrapper_WrapperManager
+ * Method:    nativeRaiseExceptionInner
+ * Signature: (I)V
+ */
+JNIEXPORT void JNICALL
+Java_org_tanukisoftware_wrapper_WrapperManager_nativeRaiseExceptionInner(JNIEnv *env, jclass clazz, jint code) {
+    log_printf(TEXT("WrapperJNI: Not Windows.  RaiseException ignored."));
+}
+
+/*
+ * Class:     org_tanukisoftware_wrapper_WrapperManager
+ * Method:    nativeRaiseFailFastExceptionInner
+ * Signature: ()V
+ */
+JNIEXPORT void JNICALL
+Java_org_tanukisoftware_wrapper_WrapperManager_nativeRaiseFailFastExceptionInner(JNIEnv *env, jclass clazz) {
+    log_printf(TEXT("WrapperJNI: Not Windows.  FailFastException ignored."));
+}
+
 /*
  * Class:     org_tanukisoftware_wrapper_WrapperManager
  * Method:    nativeRedirectPipes
