@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper.demo;
 
 /*
- * Copyright (c) 1999, 2017 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2020 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -111,7 +111,7 @@ public class DemoAppMainFrame extends JFrame implements ActionListener, WindowLi
         jMenu1.add( jMenuItem2 );
 
         JMenuItem jMenuItem3 = new JMenuItem();
-        jMenuItem3.setAccelerator( javax.swing.KeyStroke.getKeyStroke( java.awt.event.KeyEvent.VK_F4, java.awt.event.InputEvent.ALT_MASK ) );
+        jMenuItem3.setAccelerator( javax.swing.KeyStroke.getKeyStroke( java.awt.event.KeyEvent.VK_F4, java.awt.event.InputEvent.ALT_DOWN_MASK ) );
         jMenuItem3.setText( DemoApp.getRes().getString( "Close" ) );
         jMenuItem3.addActionListener( new ActionListener()
         {
