@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper.test;
 
 /*
- * Copyright (c) 1999, 2018 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2020 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -91,6 +91,7 @@ public class Main
     private static WrapperResources m_res;
     private List m_listenerFlags;
     private TextField m_slowSeconds;
+    private TextField m_suspendSeconds;
     private TextField m_serviceName;
     private TextField m_consoleTitle;
     private TextField m_childCommand;
@@ -192,6 +193,15 @@ public class Main
             buildCommand( panel, gridBag, c, getRes().getString( "Native Access Violation" ), "access_violation_native",
                     getRes().getString( "Causes an access violation using native code, the JVM will crash and be restarted." ) );
             
+            if ( WrapperManager.isWindows() )
+            {
+                buildCommand( panel, gridBag, c, getRes().getString( "Native Exception" ), "exception_native",
+                        getRes().getString( "Throw an exception using native code, on Windows, the JVM will crash and be restarted." ) );
+                
+                buildCommand( panel, gridBag, c, getRes().getString( "Native Fail Fast Exception" ), "ff_exception_native",
+                        getRes().getString( "Throw a fail fast exception using native code, on Windows, the JVM will crash and be restarted." ) );
+            }
+            
             buildCommand( panel, gridBag, c, getRes().getString( "Simulate JVM Hang" ), "appear_hung",
                     getRes().getString( "Makes the JVM appear to be hung as viewed from the Wrapper, it will be killed and restarted." ) );
             
@@ -221,6 +231,20 @@ public class Main
             buildCommand( panel, gridBag, c, getRes().getString( "System.out Deadlock" ), "deadlock_out",
                     getRes().getString( "Simulates a failure mode where the System.out object has become deadlocked." ) );
             
+            m_suspendSeconds = new TextField( "60" );
+            Panel suspendPanel = new Panel();
+            suspendPanel.setLayout( new BorderLayout() );
+            suspendPanel.add( new Label( getRes().getString( "Seconds: " ) ), BorderLayout.WEST );
+            suspendPanel.add( m_suspendSeconds, BorderLayout.CENTER );
+            Panel suspendPanel2 = new Panel();
+            suspendPanel2.setLayout( new BorderLayout() );
+            suspendPanel2.add( suspendPanel, BorderLayout.WEST );
+            suspendPanel2.add( new Label( getRes().getString( "Suspend Wrapper timeouts while the JVM is running.  (Standard, Professional)" ) ), BorderLayout.CENTER );
+            buildCommand( panel, gridBag, c, getRes().getString( "Suspend Timeouts" ), "suspend_timeouts", suspendPanel2 );
+            
+            buildCommand( panel, gridBag, c, getRes().getString( "Resume Timeouts" ), "resume_timeouts",
+                    getRes().getString( "Resume Wrapper timeouts.  (Standard, Professional)" ) );
+            
             buildCommand( panel, gridBag, c, getRes().getString( "Poll Users" ), "users",
                     getRes().getString( "Begins calling WrapperManager.getUser() and getInteractiveUser() to monitor the current and interactive users." ) );
             
@@ -406,6 +430,17 @@ public class Main
             }
             m_slowSeconds.setText( Integer.toString( slowSeconds ) );
             setSlowSeconds( slowSeconds );
+            int suspendSeconds;
+            try
+            {
+                suspendSeconds = Integer.parseInt( m_suspendSeconds.getText() );
+            }
+            catch ( NumberFormatException e )
+            {
+                suspendSeconds = 0;
+            }
+            m_suspendSeconds.setText( Integer.toString( suspendSeconds ) );
+            setSuspendSeconds( suspendSeconds );
             setServiceName( m_serviceName.getText() );
             setConsoleTitle( m_consoleTitle.getText() );
             setChildParams( m_childCommand.getText(), m_childDetached.getState() );
@@ -566,10 +601,12 @@ public class Main
             System.out.println( getRes().getString( "TestWrapper:     U: Unexpected Halt (Simulate crash)" ) );
             System.out.println( getRes().getString( "TestWrapper:     V: Access Violation (Actual crash)" ) );
             System.out.println( getRes().getString( "TestWrapper:     G: Make the JVM appear to be hung." ) );
+            System.out.println( "TestWrapper: " );
         }
         catch ( java.io.IOException e )
         {
             System.out.println( getRes().getString( "TestWrapper: Unable to open the action server socket: {0}", e.getMessage() ) );
+            System.out.println( "TestWrapper: " );
             m_actionServer = null;
         }
         
